import {
  DeleteOutlined,
  EditOutlined,
  PlusOutlined,
  QuestionCircleOutlined,
} from "@ant-design/icons";
import { Popconfirm } from "antd";
import { useState } from "react";
import { useTranslation } from "react-i18next";

export function MyDeleteIcon({
  propsPopconfirm,
  propsTooltip,
  onConfirm,
  onFetchSuccess,
  popConfirmTitle,
  popConfirmDescription,
  onClick,
}) {
  const { t } = useTranslation();
  const [open, setOpen] = useState(false);

  return (
    <MyIcon
      propsPopconfirm={{
        ...propsPopconfirm,
        icon: <QuestionCircleOutlined style={{ color: "red" }} />,
        open: open,
      }}
      propsTooltip={propsTooltip}
      onConfirm={onConfirm}
      onFetchSuccess={() => {
        setOpen(false);

        onFetchSuccess();
      }}
      onCancel={() => setOpen(false)}
      popConfirmTitle={popConfirmTitle}
      popConfirmDescription={popConfirmDescription}
      popConfirmOkText={t("common.button.delete")}
      tooltipTitle={t("common.tooltip.delete")}
      icon={
        <DeleteOutlined
          onClick={(e) => {
            setOpen(true);

            if (onClick) onClick(e);
          }}
        />
      }
    />
  );
}

export function MyEditIcon({ onClick }) {
  const { t } = useTranslation();

  return (
    <MyIcon
      popconfirmDisabled
      tooltipTitle={t("common.tooltip.edit")}
      icon={<EditOutlined onClick={onClick} />}
    />
  );
}

export function MyPlusIcon({ onClick }) {
  const { t } = useTranslation();

  return (
    <MyIcon
      popconfirmDisabled
      tooltipTitle={t("common.tooltip.add")}
      icon={<PlusOutlined onClick={onClick} />}
    />
  );
}

export function MyIcon({
  popconfirmDisabled,
  propsPopconfirm,
  // propsTooltip,
  onConfirm,
  onFetchSuccess,
  onCancel,
  popConfirmTitle,
  popConfirmDescription,
  popConfirmOkText,
  //tooltipTitle,
  icon,
}) {
  const { t } = useTranslation();

  const [isRequesting, setIsRequesting] = useState(false);

  const content = icon;
  //<Tooltip {...propsTooltip} title={tooltipTitle}>
  //{ icon };
  //</Tooltip>

  if (popconfirmDisabled) {
    return content;
  }

  return (
    <Popconfirm
      {...propsPopconfirm}
      title={popConfirmTitle}
      description={popConfirmDescription}
      okText={popConfirmOkText}
      cancelText={t("common.button.cancel")}
      okButtonProps={{ loading: isRequesting }}
      onCancel={() => {
        if (onCancel) onCancel();
      }}
      onConfirm={() => {
        setIsRequesting(true);

        onConfirm()
          .then(() => {
            setIsRequesting(false);

            onFetchSuccess();
          })
          .catch(() => {
            setIsRequesting(false);
          });
      }}
    >
      {content}
    </Popconfirm>
  );
}

/*
 <Popconfirm
  title={t(
    "employees.popConfirmDeleteEmployee.title"
  )}
  description={t(
    "employees.popConfirmDeleteEmployee.description"
  )}
  okText={t("common.button.delete")}
  onConfirm={() => {
    setIsRequesting(true);

    myFetch("/users", "DELETE", {
      userId: record.key,
    })
      .then(() => fetchEmployees())
      .catch((errStatus) => {
        console.log(errStatus);

        setIsRequesting(false);
      });
  }}
>
  <DeleteOutlined />
</Popconfirm>
*/

/*
export function MyCopyIcon({ text, notificationApi }) {
  const { t } = useTranslation();

  return (
    <Tooltip title={t("common.text.copyToClipboard")}>
      <CopyOutlined
        onClick={() => {
          navigator.clipboard.writeText(text);

          notificationApi["info"]({
            message: t("common.text.copiedToClipboard"),
          });
        }}
      />
    </Tooltip>
  );
}

export function MyShowHiddenIcon({ setIsHidden, isHidden }) {
  const { t } = useTranslation();

  return (
    <Tooltip title={isHidden ? t("common.text.hide") : t("common.text.show")}>
      {isHidden ? (
        <EyeInvisibleOutlined onClick={() => setIsHidden(false)} />
      ) : (
        <EyeOutlined onClick={() => setIsHidden(true)} />
      )}
    </Tooltip>
  );
}

export function MyReloadIcon({ onClick }) {
  const { t } = useTranslation();

  return (
    <Tooltip title={t("common.text.reload")}>
      <ReloadOutlined onClick={onClick} />
    </Tooltip>
  );
}
*/
