import { Button, Flex, Result, Spin, notification } from "antd";
import { Link, useParams, useNavigate } from "react-router-dom";
import { Constants, myFetch } from "../../../../utils";
import { useEffect, useState } from "react";
import MyCenteredContainer from "../../../../Components/MyContainer";
import { useTranslation } from "react-i18next";

export default function StoreCalendarAuth() {
  const { t } = useTranslation();
  const [notificationApi, notificationContextHolder] =
    notification.useNotification();
  const navigate = useNavigate();

  const { status } = useParams();

  const [isRequesting, setIsRequesting] = useState(true);
  const [storeId, setStoreId] = useState("");

  useEffect(() => {
    myFetch({
      url: "/calendar/store",
      method: "GET",
      notificationApi: notificationApi,
      t: t,
    })
      .then((res) => {
        if (status === "finish") {
          navigate(
            `${Constants.ROUTE_PATHS.STORE.OVERVIEW}/${res.storeId}/${Constants.ROUTE_PATHS.STORE.CALENDAR}`
          );
          return;
        }

        setIsRequesting(false);
        setStoreId(res.storeId);
      })
      .catch((err) => {
        console.log(err);
      });
  }, [status]);

  if (isRequesting) {
    return (
      <MyCenteredContainer>
        <Spin size="large" />
      </MyCenteredContainer>
    );
  }

  return (
    <>
      {notificationContextHolder}

      <Result
        status={"error"}
        title={t("calendar.authFailed.title")}
        subTitle={t("calendar.authFailed.description")}
        extra={[
          <Flex key="1" vertical>
            <Link
              to={`${Constants.ROUTE_PATHS.STORE.OVERVIEW}/${storeId}/${Constants.ROUTE_PATHS.STORE.CALENDAR}`}
            >
              <Button>{t("calendar.authFailed.button")}</Button>
            </Link>
          </Flex>,
        ]}
      />
    </>
  );
}
